export declare type TokenOptions = {
    keyword?: string;
    rightAssociative?: boolean;
    isAssign?: boolean;
    prefix?: boolean;
    postfix?: boolean;
    binop?: number;
};
export declare class TokenType {
    label: string;
    keyword?: string;
    rightAssociative: boolean;
    isAssign: boolean;
    prefix: boolean;
    postfix: boolean;
    binop: number | null;
    constructor(label: string, conf?: TokenOptions);
}
export declare class KeywordTokenType extends TokenType {
    constructor(name: string, options?: TokenOptions);
}
export declare class BinopTokenType extends TokenType {
    constructor(name: string, prec: number);
}
export declare const types: {
    num: TokenType;
    bigint: TokenType;
    regexp: TokenType;
    string: TokenType;
    name: TokenType;
    eof: TokenType;
    bracketL: TokenType;
    bracketR: TokenType;
    braceL: TokenType;
    braceBarL: TokenType;
    braceR: TokenType;
    braceBarR: TokenType;
    parenL: TokenType;
    parenR: TokenType;
    comma: TokenType;
    semi: TokenType;
    colon: TokenType;
    doubleColon: TokenType;
    dot: TokenType;
    question: TokenType;
    questionDot: TokenType;
    arrow: TokenType;
    template: TokenType;
    ellipsis: TokenType;
    backQuote: TokenType;
    dollarBraceL: TokenType;
    at: TokenType;
    hash: TokenType;
    eq: TokenType;
    assign: TokenType;
    incDec: TokenType;
    bang: TokenType;
    tilde: TokenType;
    pipeline: BinopTokenType;
    nullishCoalescing: BinopTokenType;
    logicalOR: BinopTokenType;
    logicalAND: BinopTokenType;
    bitwiseOR: BinopTokenType;
    bitwiseXOR: BinopTokenType;
    bitwiseAND: BinopTokenType;
    equality: BinopTokenType;
    lessThan: BinopTokenType;
    greaterThan: BinopTokenType;
    relationalOrEqual: BinopTokenType;
    bitShift: BinopTokenType;
    plusMin: TokenType;
    modulo: BinopTokenType;
    star: BinopTokenType;
    slash: BinopTokenType;
    exponent: TokenType;
    jsxName: TokenType;
    jsxText: TokenType;
    jsxTagStart: TokenType;
    jsxTagEnd: TokenType;
    typeParameterStart: TokenType;
    nonNullAssertion: TokenType;
    _break: KeywordTokenType;
    _case: KeywordTokenType;
    _catch: KeywordTokenType;
    _continue: KeywordTokenType;
    _debugger: KeywordTokenType;
    _default: KeywordTokenType;
    _do: KeywordTokenType;
    _else: KeywordTokenType;
    _finally: KeywordTokenType;
    _for: KeywordTokenType;
    _function: KeywordTokenType;
    _if: KeywordTokenType;
    _return: KeywordTokenType;
    _switch: KeywordTokenType;
    _throw: KeywordTokenType;
    _try: KeywordTokenType;
    _var: KeywordTokenType;
    _let: KeywordTokenType;
    _const: KeywordTokenType;
    _while: KeywordTokenType;
    _with: KeywordTokenType;
    _new: KeywordTokenType;
    _this: KeywordTokenType;
    _super: KeywordTokenType;
    _class: KeywordTokenType;
    _extends: KeywordTokenType;
    _export: KeywordTokenType;
    _import: KeywordTokenType;
    _yield: KeywordTokenType;
    _null: KeywordTokenType;
    _true: KeywordTokenType;
    _false: KeywordTokenType;
    _in: KeywordTokenType;
    _instanceof: KeywordTokenType;
    _typeof: KeywordTokenType;
    _void: KeywordTokenType;
    _delete: KeywordTokenType;
    _async: KeywordTokenType;
    _get: KeywordTokenType;
    _set: KeywordTokenType;
    _declare: KeywordTokenType;
    _readonly: KeywordTokenType;
    _abstract: KeywordTokenType;
    _static: KeywordTokenType;
    _public: KeywordTokenType;
    _private: KeywordTokenType;
    _protected: KeywordTokenType;
    _as: KeywordTokenType;
    _enum: KeywordTokenType;
    _type: KeywordTokenType;
    _implements: KeywordTokenType;
};
export declare const keywords: {
    break: KeywordTokenType;
    case: KeywordTokenType;
    catch: KeywordTokenType;
    continue: KeywordTokenType;
    debugger: KeywordTokenType;
    default: KeywordTokenType;
    do: KeywordTokenType;
    else: KeywordTokenType;
    finally: KeywordTokenType;
    for: KeywordTokenType;
    function: KeywordTokenType;
    if: KeywordTokenType;
    return: KeywordTokenType;
    switch: KeywordTokenType;
    throw: KeywordTokenType;
    try: KeywordTokenType;
    var: KeywordTokenType;
    let: KeywordTokenType;
    const: KeywordTokenType;
    while: KeywordTokenType;
    with: KeywordTokenType;
    new: KeywordTokenType;
    this: KeywordTokenType;
    super: KeywordTokenType;
    class: KeywordTokenType;
    extends: KeywordTokenType;
    export: KeywordTokenType;
    import: KeywordTokenType;
    yield: KeywordTokenType;
    null: KeywordTokenType;
    true: KeywordTokenType;
    false: KeywordTokenType;
    in: KeywordTokenType;
    instanceof: KeywordTokenType;
    typeof: KeywordTokenType;
    void: KeywordTokenType;
    delete: KeywordTokenType;
    async: KeywordTokenType;
    get: KeywordTokenType;
    set: KeywordTokenType;
    declare: KeywordTokenType;
    readonly: KeywordTokenType;
    abstract: KeywordTokenType;
    static: KeywordTokenType;
    public: KeywordTokenType;
    private: KeywordTokenType;
    protected: KeywordTokenType;
    as: KeywordTokenType;
    enum: KeywordTokenType;
    type: KeywordTokenType;
    implements: KeywordTokenType;
};
